@@ -196,7 +196,17 @@ osip_msg_build_response (osip_message_t ** dest, int status, osip_message_t * re
 	osip_message_set_header(response, "Event", event->hvalue);
 
       /* copy all record-route values */
-
+      pos=0;
+      while (!osip_list_eol(request->record_routes, pos))
+	{
+	  osip_record_route_t *rr;
+	  osip_record_route_t *rr2;
+	  rr = osip_list_get(request->record_routes, pos);
+	  i = osip_record_route_clone(rr, &rr2);
+	  if (i!=0) return -1;
+	  osip_list_add(response->record_routes, rr2, -1);
+	  pos++;
+	}
     }
 
   *dest = response;
